==> externalVector_1.0.3.tar.gz: externalVector/man/noneIndex-class.Rd <==
\name{noneIndex-class}
\docType{class}
\alias{noneIndex-class}
\alias{Arith,numeric,noneIndex-method}
\alias{Arith,noneIndex,numeric-method}
\alias{[,noneIndex,missing,missing,missing-method}
\alias{[,noneIndex,ANY,missing,missing-method}
\alias{[,noneIndex,logical,missing,missing-method}
\alias{[<-,noneIndex,ANY,ANY,ANY-method}
\alias{[[<-,noneIndex-method}
\alias{all.na,noneIndex-method}
\alias{any.na,noneIndex-method}
\alias{initialize,noneIndex-method}
\alias{length,noneIndex-method}
\alias{length<-,noneIndex-method}
\alias{dim<-,noneIndex,ANY-method}

\title{Class "noneIndex", index class representing a subscript for none
  of the elements of a vector or an array dimension }
\description{ When used as a subscript for a vector object
  or for any dimension of an array object
  this is equivalent to \code{integer(0)}. }
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("noneIndex")}.
Objects from this class can not be modified and they are all equivalent.
}
\section{Slots}{
  \describe{
    \item{\code{.Data}:}{Object of class \code{"integer"}, this is
      always equal to \code{integer(0)}. }
  }
}
\section{Extends}{
Class \code{"integer"}, directly.
Class \code{"vectorIndex"}, directly.
}
\section{Methods}{
  Signature components for the methods are:

  \tabular{ll}{
    x \tab The class "allIndex"\cr
    scalar \tab Length one positive "integer"\cr
    i \tab The class "ANY"\cr
    value \tab The class "ANY"\cr
    .Object \tab The class "allIndex"\cr
  }

  \describe{
    \item{\code{x+scalar}:}{ Add \code{scalar} to \code{x}.
      Result is \code{x}. }
    \item{\code{scalar+x}:}{ Add \code{scalar} to \code{x}.
      Result is \code{x}. }
    \item{\code{x*scalar}:}{ Multiply \code{x} by \code{scalar}.
      Result is \code{x}. }
    \item{\code{scalar*x}:}{ Multiply \code{x} by \code{scalar}.
      Result is \code{x}. }
    \item{dim(x) <- value}{ Set a dimension on \code{x}. If value is of
      length 2, this may create a "matrixIndex". }
    \item{\code{x[i]}:}{ Subset x. The result is an object of class
      \code{"NAIndex"} of length same as
      \code{length(integer(0)[i])}. }
    \item{\code{x[]}:}{ Subset x with the subscript missing. Result is x. }
    \item{\code{x[i] <- value}:}{ Subassign x. Results in an error (as
      objects from class \code{"noneIndex"} are not mutable. }
    \item{\code{x[[i]] <- value}:}{ Subassign x. Results in an error (as
      objects from class \code{"noneIndex"} are not mutable. }
    \item{\code{all.na(x)}:}{ Are all elements of \code{x} \code{NA}? Result is
      always \code{FALSE}. }
    \item{\code{any.na(x)}:}{ Is any element of \code{x} \code{NA}? Result is
      always \code{FALSE}. }
    \item{\code{initialize(.Object)}:}{Initialize an object from class
      \code{"allIndex"}. }
    \item{\code{length(x)}:}{ Return the length of \code{x} which is always
      \code{0}. }
    \item{\code{length(x) <- value}:}{ Modify the length of \code{x}. Always
      results in an error. }
  }
}
\seealso{
  \code{\link{vectorIndex-class}} for the super class of \code{"noneIndex"}.
}
\keyword{classes}

==> externalVector_1.4.0.tar.gz: externalVector/man/noneIndex-class.Rd <==
\name{noneIndex-class}
\docType{class}
\alias{noneIndex-class}
\alias{Arith,numeric,noneIndex-method}
\alias{Arith,noneIndex,numeric-method}
\alias{[,noneIndex,missing,missing,missing-method}
\alias{[,noneIndex,ANY,missing,missing-method}
\alias{[,noneIndex,logical,missing,missing-method}
\alias{[<-,noneIndex,ANY,ANY,ANY-method}
\alias{[[<-,noneIndex-method}
\alias{allNA,noneIndex-method}
\alias{anyNA,noneIndex-method}
\alias{initialize,noneIndex-method}
\alias{length,noneIndex-method}
\alias{length<-,noneIndex-method}
\alias{dim<-,noneIndex,ANY-method}

\title{Class "noneIndex", index class representing a subscript for none
  of the elements of a vector or an array dimension }
\description{ When used as a subscript for a vector object
  or for any dimension of an array object
  this is equivalent to \code{integer(0)}. }
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("noneIndex")}.
Objects from this class can not be modified and they are all equivalent.
}
\section{Slots}{
  \describe{
    \item{\code{.Data}:}{Object of class \code{"integer"}, this is
      always equal to \code{integer(0)}. }
  }
}
\section{Extends}{
Class \code{"integer"}, directly.
Class \code{"vectorIndex"}, directly.
}
\section{Methods}{
  Signature components for the methods are:

  \tabular{ll}{
    x \tab The class "allIndex"\cr
    scalar \tab Length one positive "integer"\cr
    i \tab The class "ANY"\cr
    value \tab The class "ANY"\cr
    .Object \tab The class "allIndex"\cr
  }

  \describe{
    \item{\code{x+scalar}:}{ Add \code{scalar} to \code{x}.
      Result is \code{x}. }
    \item{\code{scalar+x}:}{ Add \code{scalar} to \code{x}.
      Result is \code{x}. }
    \item{\code{x*scalar}:}{ Multiply \code{x} by \code{scalar}.
      Result is \code{x}. }
    \item{\code{scalar*x}:}{ Multiply \code{x} by \code{scalar}.
      Result is \code{x}. }
    \item{dim(x) <- value}{ Set a dimension on \code{x}. If value is of
      length 2, this may create a "matrixIndex". }
    \item{\code{x[i]}:}{ Subset x. The result is an object of class
      \code{"NAIndex"} of length same as
      \code{length(integer(0)[i])}. }
    \item{\code{x[]}:}{ Subset x with the subscript missing. Result is x. }
    \item{\code{x[i] <- value}:}{ Subassign x. Results in an error (as
      objects from class \code{"noneIndex"} are not mutable. }
    \item{\code{x[[i]] <- value}:}{ Subassign x. Results in an error (as
      objects from class \code{"noneIndex"} are not mutable. }
    \item{\code{allNA(x)}:}{ Are all elements of \code{x} \code{NA}? Result is
      always \code{FALSE}. }
    \item{\code{anyNA(x)}:}{ Is any element of \code{x} \code{NA}? Result is
      always \code{FALSE}. }
    \item{\code{initialize(.Object)}:}{Initialize an object from class
      \code{"allIndex"}. }
    \item{\code{length(x)}:}{ Return the length of \code{x} which is always
      \code{0}. }
    \item{\code{length(x) <- value}:}{ Modify the length of \code{x}. Always
      results in an error. }
  }
}
\seealso{
  \code{\link{vectorIndex-class}} for the super class of \code{"noneIndex"}.
}
\keyword{classes}
